Learn R Programming

EstMix (version 1.0.1)

calc_1d_wgs: Return mixture estimation for percentage of normal cells and tumor (1 normal + 1 tumor) with wgs data Takes baf, lrr, n_baf and nrc

Description

Return mixture estimation for percentage of normal cells and tumor (1 normal + 1 tumor) with wgs data Takes baf, lrr, n_baf and nrc

Usage

calc_1d_wgs(baf, lrr, n_baf, nrc)

Arguments

baf

a numeric vector. Each element is the mean adjusted B allele frequency for that segment, calculated as the mean of baf_tumor/baf_normal/2 for that segment

lrr

a numeric vector. Each element is the log ratio of the tumor read count and the normal read count for a segment, defined as log(tumorCount/normalCount)

n_baf

a numeric vector

nrc

a numeric vector. Each element is the normal read count of the segment divided by two

Value

sol1

a numeric number. It provides the estimated percentages of normal from the best solution. The number is the percentage of the estimated normal percentage.

sol2

a numeric number. It provides the estimated percentages of normal from the second best solution. The number is the percentage of the estimated normal percentage.